- t ('night mode can be toggled by clicking the book title')); ?>;
+ t('night mode can be toggled by clicking the book title')); ?>;
@@ -202,19 +202,19 @@
diff --git a/templates/settings-personal.php b/templates/settings-personal.php
index 36e8a7a..b17cf25 100644
--- a/templates/settings-personal.php
+++ b/templates/settings-personal.php
@@ -19,7 +19,9 @@ style('epubreader', 'settings');
/>
+ value="1" />
@@ -27,14 +29,18 @@ style('epubreader', 'settings');
/>
+ value="1" />
/>
+ value="1" />
diff --git a/templates/pdfreader.php b/templates/pdfreader.php
index 577de3c..32cfcb9 100644
--- a/templates/pdfreader.php
+++ b/templates/pdfreader.php
@@ -1,30 +1,30 @@
getAppManager()->getAppVersion('epubreader') . '.' . $revision;
+/** @var array $_ */
+/** @var OCP\IURLGenerator $urlGenerator */
+$urlGenerator = $_['urlGenerator'];
+$downloadLink = $_['downloadLink'];
+$fileId = $_['fileId'];
+$fileName = $_['fileName'];
+$fileType = $_['fileType'];
+$scope = $_['scope'];
+$cursor = $_['cursor'];
+$defaults = $_['defaults'];
+$preferences = $_['preferences'];
+$metadata = $_['metadata'];
+$annotations = $_['annotations'];
+$title = htmlentities(basename($downloadLink));
+$revision = '0130';
+$version = \OC::$server->getAppManager()->getAppVersion('epubreader') . '.' . $revision;
- /* Mobile safari, the new IE6 */
- $idevice = (strstr($_SERVER['HTTP_USER_AGENT'],'iPhone')
- || strstr($_SERVER['HTTP_USER_AGENT'],'iPad')
- || strstr($_SERVER['HTTP_USER_AGENT'],'iPod'));
+/* Mobile safari, the new IE6 */
+$idevice = (strstr($_SERVER['HTTP_USER_AGENT'], 'iPhone')
+ || strstr($_SERVER['HTTP_USER_AGENT'], 'iPad')
+ || strstr($_SERVER['HTTP_USER_AGENT'], 'iPod'));
- /* Owncloud currently does not implement CSPv3, remove this test when it does */
- $nonce = class_exists('\OC\Security\CSP\ContentSecurityPolicyNonceManager')
- ? \OC::$server->getContentSecurityPolicyNonceManager()->getNonce()
- : 'nonce_not_implemented';
+/* Owncloud currently does not implement CSPv3, remove this test when it does */
+$nonce = class_exists('\OC\Security\CSP\ContentSecurityPolicyNonceManager')
+ ? \OC::$server->getContentSecurityPolicyNonceManager()->getNonce()
+ : 'nonce_not_implemented';
?>
@@ -32,43 +32,43 @@
-
+
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
-
-
-
+
+
+